-- 八天登录
Lua_SevenDaySignInWindow = class("Lua_SevenDaySignInWindow", Lua_Window);
function Lua_SevenDaySignInWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_SevenDaySignInWindow";
	self.skinName = "SevenDaySignInWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;

	self:preLoadRes();
end

function Lua_SevenDaySignInWindow:preLoadRes()
	self:addPreLoadRes("/images/seven_day/xui_brdl_widget_1.png", Lua_LoadFileType.IMG);
	self:addPreLoadRes("/images/seven_day/xui_brdl_widget_2.png", Lua_LoadFileType.IMG);
	self:addPreLoadRes("/images/seven_day/xui_brdl_widget_3.png", Lua_LoadFileType.IMG);
	self:addPreLoadRes("/images/seven_day/xui_brdl_bg_1.png", Lua_LoadFileType.IMG);
end

function Lua_SevenDaySignInWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.heroImg:setUrl(nil);

	local posX;
	local posY;
	local item;
	local arr = DataCenter.sevenDayData.sevenDayArr;
	self.itemArr = Array();
	for i = 1, arr:getSize() do
		posX = -225 + 150 * ((i - 1) % 4);
		posY = 131 - 185 * Mathf.Ceil(i / 4);

		item = Lua_SevenDayButtonItem.new(self.content);
		item:setEnable(false);
		item:setLocation(posX, posY, 0);
		self.itemArr:add(item);
	end
	self.tweenIdx = 0;
	self:addTimer("Lua_SevenDaySignInWindow", 0.04, self, self.onPlayTween);

	self.heroImg.clickScale = false;
	self.heroNameIcon.clickScale = false;
	self.heroImg:addClickFuntion(self, self.onWinBgClick);
	self.heroNameIcon:addClickFuntion(self, self.onHeroInfoClick);
	self.drawBtn:addClickFuntion(self, self.onSingInClick);

	self:addLuaEvent("UPDATE_SEVENDAY_INFO", self, self.updateSevenDayInfo);
	Lua_ProxyManager.getProxy("Lua_SevenDayProxy"):sSevenDaySigInInfo();
end

function Lua_SevenDaySignInWindow:updateSevenDayInfo()
	local drawDay = DataCenter.sevenDayData.drawDay;
	local dayInfoArr = DataCenter.sevenDayData.sevenDayArr;
	self.heroImg:SetDimensions(0, 0);
	self.heroImg:setUrl(nil);
	self.heroImg:setUrl(dayInfoArr[drawDay].hero_url);
	self.heroImg:setLocation(dayInfoArr[drawDay].hero_pos[1], dayInfoArr[drawDay].hero_pos[2]);
	self.heroNameIcon:setAltas(dayInfoArr[drawDay].hero_name_icon[1], dayInfoArr[drawDay].hero_name_icon[2]);
	self.heroNameIcon:resetSize();
	self.wenhaoIcon:setLocation(dayInfoArr[drawDay].wenhao_pos[1], dayInfoArr[drawDay].wenhao_pos[2]);
	self.titleIcon:setAltas(dayInfoArr[drawDay].title_icon[1], dayInfoArr[drawDay].title_icon[2]);

	for i = 1, self.itemArr.getSize() do
		self.itemArr[i]:setData(dayInfoArr[i]);
	end

	local login_day = DataCenter.sevenDayData.login_day;
	login_day = drawDay < login_day and drawDay or login_day;
	local state = DataCenter.sevenDayData:getReceiveState(dayInfoArr[login_day].id);
	self.drawBtn:setGray(not state == 1);
	self.drawTxt.text = state ~= 2 and LanUtil.getValue(200800) or LanUtil.getValue(200801);
end

function Lua_SevenDaySignInWindow:onPlayTween()
	self.tweenIdx = self.tweenIdx + 1;
	if self.tweenIdx > self.itemArr:getSize() then
		self:removeTimer(self, self.onPlayTween);
		return;
	end
	local item = self.itemArr[self.tweenIdx];
	item:setEnable(true);
	TweenUtil.getInstance():addTweenTargetAlpha(item.content, 0.2, 0, -1, true);
end

function Lua_SevenDaySignInWindow:onHeroInfoClick()
	local drawDay = DataCenter.sevenDayData.drawDay;
	local dayInfoArr = DataCenter.sevenDayData.sevenDayArr;
	DataCenter.heroAtlasData:onOpenAtlasWindow(dayInfoArr[drawDay].hero_id);
end

function Lua_SevenDaySignInWindow:onSingInClick()
	local drawDay = DataCenter.sevenDayData.drawDay;
	local login_day = DataCenter.sevenDayData.login_day;
	login_day = drawDay < login_day and drawDay or login_day;
	local state = DataCenter.sevenDayData:getReceiveState(login_day);
	if state == 1 then
		Lua_ProxyManager.getProxy("Lua_SevenDayProxy"):sReceiveDayReward(login_day);
	elseif state == 2 then
		OperateAlert.showLangValue(200801);
	end
end

function Lua_SevenDaySignInWindow:dispose()
	if self.itemArr ~= nil then
		self.itemArr:dispose();
		self.itemArr:clear();
		self.itemArr = nil;
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_SevenDayButtonItem = class("Lua_SevenDayButtonItem", Lua_ListCell);
function Lua_SevenDayButtonItem:ctor(p)
	self:superCall("ctor", p, "SevenDayButton_skin");
end

function Lua_SevenDayButtonItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setLocation(1, -13, 0);
	self.itemIcon:setScale(0.95, 0.95);
end

function Lua_SevenDayButtonItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	local state = DataCenter.sevenDayData:getReceiveState(data.id);
	if state == 1 then
		self.itemBg:setAltas("seven_day_atlas", "xui_brdl_widget_5");
		self.dayTxt.colorStr = Lua_ColorDefine.transColorStr("FCF4AA");
		self.dayTxt.effectColorStr = Lua_ColorDefine.transColorStr("8B4823");
	else
		self.itemBg:setAltas("seven_day_atlas", "xui_brdl_widget_4");
		self.dayTxt.colorStr = Lua_ColorDefine.transColorStr("FFFFFF");
		self.dayTxt.effectColorStr = Lua_ColorDefine.transColorStr("536477");
	end
	self.dayTxt.text = LanUtil.formateStr(200802, data.id);

	local tvo = Lua_ToolVo.createToolVo(data.reward[1], data.reward[2]);
	self.itemIcon:setData(tvo);
	self.itemIcon:setDrawMask(state == 2);
	self.itemIcon:setClick(self, self.onBtnClick);
end

function Lua_SevenDayButtonItem:onBtnClick()
	local state = DataCenter.sevenDayData:getReceiveState(self.data.id);
	if state == 0 then
		OperateAlert.show(LanUtil.formateStr(200803, self.data.id));
		DataCenter.packUtil:showItemInfo(self.itemIcon.data, self.itemIcon.isShowBtns);
	elseif state == 1 then
		local drawDay = DataCenter.sevenDayData.drawDay;
		if self.data.id > drawDay then
			OperateAlert.showLangValue(200804);
		else
			Lua_ProxyManager.getProxy("Lua_SevenDayProxy"):sReceiveDayReward(drawDay);
		end
	else
		OperateAlert.showLangValue(200801);
		DataCenter.packUtil:showItemInfo(self.itemIcon.data, self.itemIcon.isShowBtns);
	end
end

function Lua_SevenDayButtonItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end